/*
  Copyright (c) 2003, 2004 Darren Horrocks
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
    1. Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.
    3. The name of the author may not be used to endorse or promote products
       derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
  IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/* 
  Darrens Generic Maped Seek Script v1.0
  usage

  you must put this at the bottom of the layout or group that the volume
  layer is in

  <script file="path/to/script/seek.maki" param="layerid;mapid"/>
*/

#include <lib/std.mi>

Function int getFromMap(int x, int y);

Global Group thisGroup;
Global Layer thisLayer;
Global Map thisMap;
Global Timer seekTimer;
Global Boolean seekClicked;

int getFromMap(int x, int y) {
  int retval = thisMap.getValue(x-thisLayer.getLeft(),y-thisLayer.getTop());
  return retval;
}

System.onScriptLoaded() {
  String sParams = getParam();
  string layerID = getToken(sParams,";",0);
  string mapID = getToken(sParams,";",1);

  thisGroup = getScriptGroup();
  thisLayer = thisGroup.getObject(layerID);

  thisMap = new map;
  thisMap.loadMap(mapID);

  seekClicked = 0;

  seekTimer = new timer;
  seekTimer.setDelay(10);
  seekTimer.start();
}

seekTimer.onTimer() {
  System.onSeek(getPosition());
}

System.onSeek(int newpos) {
  if (newpos <= 0) return;
  int len = getPlayItemLength();
  if(len <= 0) return;
  int devby = len/255;
  if(devby <= 0) return;
  thisLayer.setRegionFromMap(thisMap,newpos/devby,1);
}

thisLayer.onLeftButtonDown(int x, int y) {
  //onSeek(getFromMap(x,y));
  seekClicked = 1;
}

thisLayer.onLeftButtonUp(int x, int y) {
  //onSeek(getFromMap(x,y));
  seekClicked = 0;
}

thisLayer.onMouseMove(int x, int y) {
  if(seekClicked == 1) {
    //if(!thisMap.inRegion(x,y)) return;
    int len = getPlayItemLength();
    if(len <= 0) return;
    int devby = len/255;
    seekTo(getFromMap(x, y)*devby);
  }
}